import GraphEditor from "@web/src/components/common/editor/graph/GraphEditor";
import { usePost } from "@nice/client";
import React, { useState, useCallback } from "react";
import * as tus from "tus-js-client";
import toast from "react-hot-toast";
interface TusUploadProps {
	onSuccess?: (response: any) => void;
	onError?: (error: Error) => void;
}
const TusUploader: React.FC<TusUploadProps> = ({ onSuccess, onError }) => {
	const { create } = usePost();
	const [progress, setProgress] = useState<number>(0);
	const [isUploading, setIsUploading] = useState<boolean>(false);
	const [uploadError, setUploadError] = useState<string | null>(null);
	const handleFileUpload = useCallback(
		(file: File) => {
			if (!file) return;
			setIsUploading(true);
			setProgress(0);
			setUploadError(null);
			// Extract file extension
			const extension = file.name.split(".").pop() || "";
			const upload = new tus.Upload(file, {
				endpoint: "http://localhost:3000/upload",
				retryDelays: [0, 1000, 3000, 5000],
				metadata: {
					filename: file.name,
					size: file.size.toString(),
					mimeType: file.type,
					extension: extension,
					modifiedAt: new Date(file.lastModified).toISOString(),
				},
				onProgress: (bytesUploaded, bytesTotal) => {
					const percentage = (
						(bytesUploaded / bytesTotal) *
						100
					).toFixed(2);
					setProgress(Number(percentage));
				},
				onSuccess: () => {
					setIsUploading(false);
					setProgress(100);
					onSuccess?.(upload);
				},
				onError: (error) => {
					setIsUploading(false);
					setUploadError(error.message);
					onError?.(error);
				},
			});

			upload.start();
		},
		[onSuccess, onError]
	);

	return (
		<div>
			<button
				onClick={async () => {
					try {
						await create.mutateAsync({
							data: {
								title: "123",
								isPublic: true,
							},
						});
						toast.success("创建成功");
					} catch (err) {
						console.log(err);
						toast.error("创建失败");
					}
				}}>
				123
			</button>
			<div className="w-full" style={{ height: 800 }}>
				<GraphEditor></GraphEditor>
			</div>

			<input
				type="file"
				onChange={(e) => {
					const file = e.target.files?.[0];
					if (file) handleFileUpload(file);
				}}
			/>
			{isUploading && (
				<div>
					<progress value={progress} max="100" />
					<span>{progress}%</span>
				</div>
			)}
			{uploadError && (
				<div style={{ color: "red" }}>上传错误: {uploadError}</div>
			)}
		</div>
	);
};

export default TusUploader;
